@@ -11,7 +11,7 @@ hsp_max_parsimony = function(	tree,
 	
 	# basic error checking
 	if(length(tip_states)!=Ntips) stop(sprintf("ERROR: Length of tip_states (%d) is not the same as the number of tips in the tree (%d)",length(tip_states),Ntips));
-	if(!is.integer(tip_states)) stop(sprintf("ERROR: tip_states must be integers"))
+	if(!is.numeric(tip_states)) stop(sprintf("ERROR: tip_states must be integers"))
 	if(check_input){
 		if((!is.null(names(tip_states))) && any(names(tip_states)!=tree$tip.label)) stop("ERROR: Names in tip_states and tip labels in tree don't match (must be in the same order).")
 	}
